@@ -19,17 +19,22 @@ which pkg-config || {
 	exit 1
 }
 
+echo -n "checking for libtoolize... "
+which libtoolize || {
+	echo "*** No libtoolize (libtool) found, please install it ***"
+	exit 1
+}
 echo -n "checking for gtkdocize... "
 if which gtkdocize ; then
 	gtkdocize --copy || exit 1
 else
-	echo "*** No gtkdocize found, skipping documentation ***"
+	echo "*** No gtkdocize (gtk-doc) found, skipping documentation ***"
 	echo "EXTRA_DIST = " > gtk-doc.make
 fi
 
 echo -n "checking for autoreconf... "
 which autoreconf || {
-	echo "*** No autoreconf found, please install it ***"
+	echo "*** No autoreconf (autoconf) found, please install it ***"
 	exit 1
 }
 
